*********************
Programming Resources
*********************

.. toctree::
  :maxdepth: 1
  :hidden:

HTML
----

`W3 Schools HTML <https://www.w3schools.com/html/>`_ - Contains an excellent step-by-step tutorial, as well as a comprehensive tag reference.


CSS
---

`W3 Schools CSS <https://www.w3schools.com/css/default.asp>`_ - Just like HTML, walks through a number of the common styling options and includes a comprehensive reference.

`Bootstrap <https://getbootstrap.com/docs/4.0/getting-started/introduction/>`_ - CSS framework used in much of the TOM Toolkit via a specific PyPi package. The site contains a tutorial on the built-in CSS styles available for use.

`django-bootstrap4 <https://django-bootstrap4.readthedocs.io/en/latest/index.html>`_ - Reference guide for the PyPi package that provides Bootstrap4 elements in Django.


Django
------

`Official Django Docs <https://docs.djangoproject.com/en/2.2/>`_ - The first-rate official documentation of Django. If you're unfamiliar with Django, start with the `step-by-step tutorial <https://docs.djangoproject.com/en/2.2/intro/tutorial01/>`_. If you're looking for a reference, the docs contain topic-specific guides, "recipes", and API documentation.

`Django Girls Tutorial <https://tutorial.djangogirls.org/en/>`_ - If the official Django tutorial is more technical than you prefer, check out Django Girls. If you know Python and are just looking to familiarize yourself with Django, start with the `"What is Django? <https://tutorial.djangogirls.org/en/django/>`_ chapter.

`Classy Class-Based Views <https://ccbv.co.uk/projects/Django/2.2/>`_ - Inheritance can be confusing. The CCBV reference page shows the class hierarchy of Django's built-in class-based views, along with the available attributes and methods, and the class they each come from.

`Databases <https://docs.djangoproject.com/en/3.0/ref/databases/>`_ - Information on setting up different database backends in Django.

`Security in Django <https://docs.djangoproject.com/en/2.2/topics/security/>`_ - Make sure your Django application is secure.


Python
------

`Dive Into Python <https://diveintopython3.problemsolving.io/>`_ - For anyone looking for a Python refresher.

`Official Python Reference <https://docs.python.org/3/>`_ - Naturally.
